@@ -10,6 +10,8 @@ from dataclasses import dataclass, field
 
 from hopeit.dataobjects import dataobject
 from hopeit.server.names import auto_path_prefixed
+from hopeit.server.version import ENGINE_VERSION
+
 
 __all__ = ['StreamsConfig',
            'LoggingConfig',
@@ -31,8 +33,8 @@ class StreamsConfig:
     """
     :field connection_str: str, url to connect to streams server: i.e. redis://localhost:6379
     """
-    stream_manager: str = "hopeit.streams.redis.RedisStreamManager"
-    connection_str: str = '<<DEFAULT>>'
+    stream_manager: str = "hopeit.streams.NoStreamManager"
+    connection_str: str = '<<NoStreamManager>>'
     delay_auto_start_seconds: int = 3
 
 
@@ -85,10 +87,17 @@ class APIConfig:
 @dataobject
 @dataclass
 class ServerConfig:
+    """
+    Server configuration
+    """
     streams: StreamsConfig = field(default_factory=StreamsConfig)
     logging: LoggingConfig = field(default_factory=LoggingConfig)
     auth: AuthConfig = field(default_factory=AuthConfig.no_auth)
     api: APIConfig = field(default_factory=APIConfig)
+    engine_version: str = field(default=ENGINE_VERSION)
+
+    def __post_init__(self):
+        self.engine_version = ENGINE_VERSION
 
 
 def parse_server_config_json(config_json: str) -> ServerConfig:
